Package: grattanInflators
Title: Inflators for Australian Policy Analysis
Version: 0.5.7
Authors@R: 
    person(given = "Hugh",
           family = "Parsonage",
           role = c("aut", "cre"),
           email = "hugh.parsonage@gmail.com")
Description: Using Australian Bureau of Statistics indices, provides functions
    that convert historical, nominal statistics to real, contemporary values 
    without worrying about date input quality, performance, or the ABS catalogue.
License: GPL-2
Encoding: UTF-8
Depends: R (>= 4.0.0)
Imports: data.table, fy, hutils, tools, utils
RoxygenNote: 7.3.3
Suggests: distributional, fable, fabletools, tinytest, withr
NeedsCompilation: yes
Packaged: 2026-01-12 12:54:36 UTC; hughp
Author: Hugh Parsonage [aut, cre]
Maintainer: Hugh Parsonage <hugh.parsonage@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-12 13:40:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 00:50:41 UTC; unix
Archs: grattanInflators.so.dSYM
