# Generated by roxygen2: do not edit by hand

export(Inflate)
export(content2series_id)
export(cpi_inflator)
export(cpi_monthly_excl_volatile)
export(cpi_monthly_original)
export(cpi_monthly_seasonal)
export(cpi_original)
export(cpi_seasonal)
export(cpi_trimmed_mean)
export(download_data)
export(dr2index)
export(fast_as_idate)
export(grattanInflators_has_no_data)
export(lf_inflator)
export(lfi_original)
export(lfi_seasonal)
export(lfi_trend)
export(wage_inflator)
export(when_last_updated)
export(wpi_original)
export(wpi_seasonal)
export(wpi_trend)
import(data.table)
importFrom(fy,fy2date)
importFrom(hutils,prohibit_vector_recycling)
importFrom(hutils,provide.file)
importFrom(hutils,samp)
importFrom(stats,complete.cases)
importFrom(tools,R_user_dir)
importFrom(utils,download.file)
importFrom(utils,hasName)
importFrom(utils,head)
importFrom(utils,packageName)
useDynLib(grattanInflators, .registration=TRUE)
